#
# spec file for package python-scikit-image
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define srcname scikit_image
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
Name:           python-scikit-image%{psuffix}
Version:        0.22.0
Release:        1.2
Summary:        Collection of algorithms for image processing in Python
License:        BSD-3-Clause
URL:            https://scikit-image.org/
Source0:        https://files.pythonhosted.org/packages/source/s/scikit-image/%{srcname}-%{version}.tar.gz
BuildRequires:  %{python_module Cython >= 0.29.21}
BuildRequires:  %{python_module devel >= 3.7}
BuildRequires:  %{python_module meson-python}
BuildRequires:  %{python_module numpy-devel >= 1.21.1}
BuildRequires:  %{python_module packaging >= 20}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pythran}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  freeimage-devel
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
Requires:       python-Pillow >= 9.0.1
Requires:       python-PyWavelets >= 1.1.1
Requires:       python-imageio >= 2.7
Requires:       python-lazy-loader >= 0.2
Requires:       python-networkx >= 2.8
Requires:       python-numpy >= 1.21.1
Requires:       python-packaging >= 21.0
Requires:       python-scipy >= 1.8
Requires:       python-tifffile >= 2022.8.12
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-QtPy
Recommends:     python-SimpleITK
Recommends:     python-astropy >= 3.1.2
Recommends:     python-cloudpickle >= 0.2.1
Recommends:     python-dask-array >= 1.0.0
Recommends:     python-imread >= 0.5.1
Recommends:     python-matplotlib >= 3.0.3
Recommends:     python-pooch >= 1.3.0
Recommends:     python-pyamg
%if %{with test}
BuildRequires:  %{python_module dask-array >= 1.0.0}
BuildRequires:  %{python_module matplotlib >= 3.0.3}
BuildRequires:  %{python_module numpydoc}
BuildRequires:  %{python_module pytest >= 4.0}
BuildRequires:  %{python_module pytest-localserver}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module scikit-image = %{version}}
%endif
# /SECTION
%python_subpackages

%description
Scikit-image is a collection of algorithms for image processing in Python.
It is available free of charge and free of restriction.

%prep
%if !%{with test}
%autosetup -p1 -n %{srcname}-%{version}
sed -Ei "1{s@/usr/bin/env python@%{_bindir}/python3@}" ./skimage/_build_utils/*.py
%else
%setup -q -c scikit-image-%{version}-test -D -T
%endif

%build
%if !%{with test}
%pyproject_wheel
%endif

%install
%if !%{with test}
%pyproject_install
%{python_expand %fdupes %{buildroot}%{$python_sitearch}
chmod -x %{buildroot}%{$python_sitearch}/skimage/measure/{__init__,_find_contours}.py
}
%endif

%if %{with test}
%check
# fails randomly https://github.com/scikit-image/scikit-image/issues/3237
donttest+="test_wrap_around"
# fails randomly on all platforms
donttest+=" or test_structural_similarity_dtype"
# https://github.com/scikit-image/scikit-image/issues/7051
donttest+=" or test_ellipse_parameter_stability"
# Another floating point flaky test (works for now, but let's keep it commented just in case)
#donttest+=" or test_clear_border_non_binary_out"
export PYTEST_DEBUG_TEMPROOT=$(mktemp -d -p ./)
%pytest_arch -v --pyargs skimage -n auto -k "not ($donttest)"
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE.txt
%doc CONTRIBUTORS.txt TODO.txt
%{python_sitearch}/skimage/
%{python_sitearch}/scikit_image-%{version}*-info
%endif

%changelog
* Sat Mar 16 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.22.0:
  * Long list of changes, see
    https://scikit-image.org/docs/stable/release_notes/release_0.22.html
- Drop upstreamed patches
  * np-warn.patch
  * skimage-numpy125.patch
- Enable no longer failing tests.
* Tue Aug 22 2023 Markéta Machová <mmachova@suse.com>
- Add upstream patches np-warn.patch and skimage-numpy125.patch
  to fix build with NumPy 1.25
* Thu Jul  6 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.21.0
  * Too many changes to list, see
    https://github.com/scikit-image/scikit-image/releases/tag/v0.21.0
- Update minimum versions of Requires/BuildRequires in keeping
  with upstream.
- Use pyproject_* macros to build and install since there is no
  setup.py any more.
- Drop skimage-fix-module-install.patch: fixed upstream.
- Fix some hashbangs before build.
- New Requires: python-lazy-loader.
- Set PYTEST_DEBUG_TEMPROOT to a tmp dir created within the
  working dir as tests now require it to be writable.
- Some more tests disabled due to flaky floating point issues.
* Fri Jul  1 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.19.3
  * Revert unintentional change to default multichannel behavior
    introduced in v0.19.0 for skimage.restoration.cycle_spin (now
    defaults to single channel again)
  * Fix corner case with an optimal angle of 0 degrees in
    hough_line_peaks
  * Fixed the gallery example involving registration with log-polar
    transformations
  * Update test suite for compatibility with the most recent
    tifffile release.
  * warp/rotate: fixed a bug with clipping when cval is not in the
    input range
  * Fix computation of histogram bins for multichannel
    integer-valued images
  * Update skimage.future.manual_polygon_segmentation to work with
    Matplotlib 3.5.
  * Update skimage.io.imread to avoid warnings when using
    imageio>=2.16.2.
  * Now compatible with Pillow >= 9.1 (palette may contain <256
    entries)
  * Added support for NumPy 1.23
- Release 0.19.2
  * This is primarily a bug fix release, although there is one new
    gallery example related to detection of fluorescence at the
    nuclear envelope of mammalian cells.
- Release 0.19.1
  * This is a small bug fix release that resolves a couple of
    backwards compatibility issues.
- Release 0.19.0
  * A highlight of this release is the addition of the popular
    scale-invariant feature transform (SIFT) feature detector and
    descriptor. This release also introduces a perceptual blur
    metric, new pixel graph algorithms, and most functions now
    operate in single-precision when single-precision inputs are
    provided. Many other bug fixes, enhancements and performance
    improvements are detailed below.
  * A significant change in this release is in the treatment of
    multichannel images. The existing multichannel argument to
    functions has been deprecated in favor of a new channel_axis
    argument. channel_axis can be used to specify which axis of an
    array contains channel information (with channel_axis=None
    indicating a grayscale image).
  * scikit-image now uses "lazy loading", which enables users to
    access the functions from all skimage submodules without the
    overhead of eagerly importing all submodules. As a concrete
    example, after calling "import skimage" a user can directly
    call a function such as skimage.transform.warp whereas
    previously it would have been required to first "import
    skimage.transform".
  * An exciting change on the development side is the introduction
    of support for Pythran as an alternative to Cython for
    generating compiled code. We plan to keep Cython support as
    well going forward, so developers are free to use either one as
    appropriate. For those curious about Pythran, a good overview
    was given in the SciPy 2021 presentation, "Building SciPy
    Kernels with Pythran"
    (https://www.youtube.com/watch?v=6a9D9WL6ZjQ).
  * This release now supports Python 3.7-3.10.
- Release 0.18.3
  * This is a small bugfix release for compatibility with Pooch 1.5
    and SciPy 1.7.
- Release 0.18.2
  * This release fixes a couple of minor bugs.
- Add skimage-fix-module-install.patch
  * gh#scikit-image/scikit-image#6428
* Fri Jan 22 2021 Benjamin Greiner <code@bnavigator.de>
- Update to 0.18.1
  * Fix indexing error for labelling in large (>2GB) arrays (#5143,
    [#5151])
  * Only use retry_if_failed with recent pooch (#5148)
- Announcement: scikit-image 0.18.0
  * We're happy to announce the release of scikit-image v0.18.0!
  * scikit-image is an image processing toolbox for SciPy
    that includes algorithms for segmentation, geometric
    transformations, color space manipulation, analysis,
    filtering, morphology, feature detection, and more.
  * This release of scikit-image drops support for Python
    3.6 in accordance with the NEP-29 Python and Numpy
    version support community standard
    <https://numpy.org/neps/nep-0029-deprecation_policy.html>_:
    Python 3.7 or
    newer is required to run this version.
  * For more information, examples, and documentation,
    please visit our website: https://scikit-image.org
  New Features
  * Add the iterative Lucas-Kanade (iLK) optical flow method
    (#4161)
  * Add Feret diameter in region properties (#4379, #4820)
  * Add functions to compute Euler number and Crofton perimeter
    estimation (#4380)
  * Add a function to compute the Hausdorff distance (#4382)
  * Added 3D support for many filters in skimage.filters.rank.
  * An experimental implementation of trainable pixel
    segmentation, aiming for
    compatibility with the scikit-learn API, has been added to
    skimage.future. Try it out! (#4739)
  * Add a new function segmentation.expand_labels to dilate labels
    while preventing overlap (#4795)
  * It is now possible to pass extra measurement functions to
    measure.regionprops and regionprops_table (#4810)
  * Add rolling ball algorithm for background subtraction (#4851)
  * New sample images have been added in the data subpackage:
    data.eagle
  * (#4922), data.human_mitosis (#4939), data.cells3d (#4951), and
  * data.vortex (#5041). Also note that the image for data.camera
    has been changed due to copyright issues (#4913).
  * skimage.feature.structure_tensor now supports 3D (and nD)
    images as input (#5002)
  * Many thresholding methods can now receive a precomputed
    histogram as input, resulting in significant speedups if
    multiple methods are tried on the same image, or if a fast
    histogram method is used. (#5006)
  * measure.regionprops now supports multichannel intensity images
    (#5037)
  Documentation
  * Add an example to the flood fill tutorial (#4619)
  * Docstring enhancements for marching cubes and find_contours
    (#4641)
  * A new tutorial presenting a cell biology example has been
    added to the gallery (#4648). Special thanks to Pierre Poulain
    and Fred Bernard (Université de Paris and Institut Jacques
    Monod) for scientific review of this example!
  * Improve register rotation example with notes and references
    (#4723)
  * Add versionadded for new scalar type support for "scale" param
    in transform.AffineTransform (#4733)
  * New tutorial on visualizing 3D data <https://scikit-image.org/
    docs/dev/auto_examples/applications/
    plot_3d_image_processing.html>_ (#4850)
  * Add example for 3D adaptive histogram equalization (AHE)
    (#4658)
  * Automatic formatting of docstrings for improved consistency
    (#4849)
  * Improved docstring for rgb2lab (#4839) and marching_cubes
    (#4846)
  * Improved docstring for measure.marching_cubes, mentioning how
    to decimate a mesh using mayavi (#4846)
  * Document how to contribute a gallery example. (#4857)
  * Fix and improve entropy example (#4904)
  * expand the benchmarking section of the developer docs (#4905)
  * Improved docstring for util.random_noise (#5001)
  * Improved docstrings for morphology.h_maxima and
    morphology.h_minima (#4929).
  * Improved docstring for util.img_as_int (#4888).
  * A new example demonstrates interactive exploration of
    regionprops results using the PyData stack (pandas, seaborn)
    at https://scikit-image.org/docs/dev/auto_examples/segmentation/plot_regionprops.html
    (#5010).
  * Documentation has been added to explain how to download
    example datasets <https://scikit-image.org/docs/dev/install.html#downloading-all-demo-datasets>_
    which are not installed with scikit-image (#4984). Similarly,
    the contributor guide has been updated to mention how to host
    new datasets in a gitlab repository (#4892).
  * The benchmarking section of the developer documentation
    <https://scikit-image.org/docs/dev/contribute.html#benchmarks>_
    has been expanded (#4905).
  * Added links to the image.sc forum in example pages (#5094,
    [#5096])
  * Added missing datasets to gallery examples (#5116, #5118)
  * Add farid filters in all, to populate the documentation
    (#5128, #5129)
  * Proofread gallery example for rank filters. (#5126, #5136)
  Improvements
  * float32 support for SLIC (#4683), ORB (#4684, #4697), BRIEF
    (#4685),
  * pyramid_gaussian (#4696), Richardson-Lucy deconvolution (#4880)
  * In skimage.restoration.richardson_lucy, computations are now
    done in single-precision when the input image is single-
    precision. This can give a substantial performance improvement
    when working with single precision data.
  * Richardson-Lucy deconvolution now has a filter_epsilon keyword
    argument to avoid division by very small numbers (#4823)
  * Add default level parameter (max-min) / 2 in
    measure.find_contours (#4862)
  * The performance of the SLIC superpixels algorithm
    (skimage.segmentation.slice) was improved for the case where a
    mask is supplied by the user (#4903). The specific superpixels
    produced by masked SLIC will not be identical to those
    produced by prior releases.
  * exposure.adjust_gamma has been accelerated for uint8 images by
    using a look-up table (LUT) (#4966).
  * measure.label has been accelerated for boolean input images,
    by using scipy.ndimage's implementation for this case (#4945).
  * util.apply_parallel now works with multichannel data (#4927).
  * skimage.feature.peak_local_max supports now any Minkowski
    distance.
  * We now use sparse cross-correlation to accelerate local
    thresholding functions (#4912)
  * morphology.convex_hull_image now uses much less memory by
    checking hull inequalities in sequence (#5020)
  * Polygon rasterization is more precise and will no longer
    potentially exclude input vertices. (#5029)
  * Add data optional requirements to allow pip install scikit-
    image[data] (#5105, #5111)
  * OpenMP support in MSVC (#4924, #5111)
  * Restandardize handling of Multi-Image files (#2815, #5132)
  * Consistent zoom boundary behavior across SciPy versions (#5131,
    [#5133])
  API Changes
  * skimage.restoration.richardson_lucy returns a single-precision
    output when the input is single-precision. Prior to this
    release, double-precision was always used. (#4880)
  * The default value of threshold_rel in skimage.feature.corner
    has changed from 0.1 to None, which corresponds to letting
  * skimage.feature.peak_local_max decide on the default. This is
    currently equivalent to threshold_rel=0.
  * In measure.label, the deprecated neighbors parameter has been
    removed. (#4942)
  * The image returned by data.camera has changed because of
    copyright issues (#4913).
  Bug fixes
  * A bug in label2rgb has been fixed when the input image had
    np.uint8 dtype (#4661)
  * Fixed incorrect implementation of skimage.color.separate_stains
    (#4725)
  * Many bug fixes have been made in peak_local_max (#2592, #4756,
    [#4760], #5047)
  * Fix bug in random_walker when input labels have negative values
    (#4771)
  * PSF flipping is now correct for Richardson-Lucy deconvolution
    work in >2D (#4823)
  * Fix equalize_adapthist (CLAHE) for clip value 1.0 (#4828)
  * For the RANSAC algorithm, improved the case where all data
    points are outliers, which was previously raising an error
    (#4844)
  * An error-causing bug has been corrected for the bg_color
    parameter in label2rgb when its value is a string (#4840)
  * A normalization bug was fixed in
    metrics.variation_of_information (#4875)
  * Euler characteristic property of skimage.measure.regionprops
    was erroneous for 3D objects, since it did not take tunnels
    into account. A new implementation based on integral geometry
    fixes this bug (#4380).
  * In skimage.morphology.selem.rectangle the height argument
    controlled the width and the width argument controlled the
    height. They have been replaced with nrow and ncol. (#4906)
  * skimage.segmentation.flood_fill and skimage.segmentation.flood
    now consistently handle negative values for seed_point.
  * Segmentation faults in segmentation.flood have been fixed
    (#4948, #4972)
  * A segfault in draw.polygon for the case of 0-d input has been
    fixed (#4943).
  * In registration.phase_cross_correlation, a ValueError is raised
    when NaNs are found in the computation (as a result of NaNs in
    input images). Before this fix, an incorrect value could be
    returned where the input images had NaNs (#4886).
  * Fix edge filters not respecting padding mode (#4907)
  * Use v{} for version tags with pooch (#5104, #5110)
  * Fix compilation error in XCode 12 (#5107, #5111)
  Deprecations
  * The indices argument in skimage.feature.peak_local_max has been
    deprecated. Indices will always be returned. (#4752)
  * In skimage.feature.structure_tensor, an order argument has been
    introduced which will default to 'rc' starting in version 0.20.
    (#4841)
  * skimage.feature.structure_tensor_eigvals has been deprecated
    and will be removed in version 0.20. Use
    skimage.feature.structure_tensor_eigenvalues instead.
  * The skimage.viewer subpackage and the skivi script have been
    deprecated and will be removed in version 0.20. For interactive
    visualization we recommend using dedicated tools such as napari
    <https://napari.org>_ or plotly <https://plotly.com>_. In a
    similar vein, the qt and skivi plugins of skimage.io have been
    deprecated and will be removed in version 0.20. (#4941, #4954)
  * In skimage.morphology.selem.rectangle the arguments width and
    height have been deprecated. Use nrow and ncol instead.
  * The explicit setting threshold_rel=0` was removed from the
    Examples of the following docstrings: skimage.feature.BRIEF,
    skimage.feature.corner_harris,
    skimage.feature.corner_shi_tomasi,
    skimage.feature.corner_foerstner, skimage.feature.corner_fast,
    skimage.feature.corner_subpix, skimage.feature.corner_peaks,
    skimage.feature.corner_orientations, and
    skimage.feature._detect_octave``.
  * In skimage.restoration._denoise, the warning regarding
    rescale_sigma=None was removed.
  * In skimage.restoration._cycle_spin, the # doctest: +SKIP was
    removed.
* Thu Jan  7 2021 Markéta Machová <mmachova@suse.com>
- Deleted patches:
  * scikit-image-pr4735-ragged.patch
  * scikit-image-pr4731-floatingwarnings.patch
* Wed Aug 12 2020 Benjamin Greiner <code@bnavigator.de>
- Apply patches to fix errors due to numpy warnings
  * scikit-image-pr4731-floatingwarnings.patch
    gh#scikit-image/scikit-image#4731
  * scikit-image-pr4735-ragged.patch
    gh#scikit-image/scikit-image#4735
- Update requirements
- make multibuild
* Sat May 30 2020 Arun Persaud <arun@gmx.de>
- update to version 0.17.2:
  * Bug fixes
    + We made pooch an optional dependency, since it has been added as
    required dependency by mistake (#4666), and we fixed a bug about
    the path used for pooch to download data (#4662)
    + The support of float 32 images was corrected for slic
    segmentation, ORB and BRIEF feature detectors (#4683, #4684,
    [#4685], #4696, #4697)
    + We removed deprecated arguments (#4691)
    mask, shift_x, and shift_y from skimage.filters.median
    beta1 and beta2 from skimage.filters.frangi
    beta1 and beta2 from skimage.filters.hessian
    dtype from skimage.io.imread
    img from skimage.morphology.skeletonize_3d.
    + Gallery examples were updated to suppress warnings and take into
    account new default values in some functions (#4692 and #4676)
* Tue May 12 2020 Tomáš Chvátal <tchvatal@suse.com>
- We need at least pytest 4.x series
* Sat May  9 2020 Arun Persaud <arun@gmx.de>
- update to version 0.17.1:
  * fixed bug in label2rgb
- changes from version 0.17.0:
  * New Features
    + Hyperparameter calibration of denoising algorithms with
    restoration.calibrate_denoiser (#3824), with corresponding
    gallery example and tutorial.
    + measure.profile_line has a new reduce_func parameter to accept a
    reduction operation to be computed on pixel values along the
    profile (#4206)
    + nD windows for reducing spectral leakage when computing the FFT
    of n-dimensional images, with filters.window (#4252) (with new
    gallery example)
    + Add Minkowski distance metric support to corner_peak (#4218)
    + util.map_array was introduced to map a set of pixel values to
    another one (for example to map region labels to the size of
    regions in an image of labels) #4612 and #4646
    + Masked marching cubes (#3829)
    + The SLIC superpixel algorithm now accepts a mask to exclude some
    parts of the image and force the superpixel boundaries to follow
    the boundary of the mask (#3850)
    + Pooch -- on the fly download of datasets from github: we
    introduced the possibility to include larger datasets in the
    data submodule, thanks to the pooch library. data.download_all
    fetches all datasets. (#3945)
    + Starting with this version, our gallery examples now have links
    to run the example notebook on a binder instance. (#4543)
    + New doc tutorials and gallery examples have been added to the
    use of regionprops_table (#4348) geometrical transformations
    (#4385), and the registration of rotation and scaling with no
    shared center (#4515). A new section on registration has been
    added to the gallery (#4575).
  * Improvements
    + scikit-image aims at being fully compatible with 3D arrays, and
    when possible with nD arrays. nD support has been added to color
    conversion functions (#4418), to the CLAHE
    exposure.equalize_adapthist algorithm (#4598) and to the Sobel,
    Scharr, and Prewitt filters (#4347).
    + Multichannel support for denoise_tv_bregman (#4446)
    + The memory footprint of segmentation.relabel_sequential has been
    reduced in the case of labels much larger than the number of
    labels (#4612)
    + Random ellipses are now possible in draw.random_shapes (#4493)
    + Add border conditions to ridge filters (#4396)
    + segmentation.random_walker new Jacobi preconditioned conjugate
    gradient mode (#4359) and minor corrections #4630
    + Warn when rescaling with NaN in exposure.intensity_range (#4265)
    + We have also improved the consistency of several functions
    regarding the way they handle data types
    + Make dtype consistent in filters.rank functions (#4289)
    + Fix colorconv float32 to double cast (#4296)
    + Prevent radon from upcasting float32 arrays to double (#4297)
    + Manage iradon_sart input and output data type (#4300)
  * API Changes
    + When used with floating point inputs, denoise_wavelet no longer
    rescales the range of the data or clips the output to the range
    [0, 1] or [-1, 1]. For non-float inputs, rescaling and clipping
    still occurs as in prior releases (although with a bugfix
    related to the scaling of sigma).
    + For 2D input, edge filters (Sobel, Scharr, Prewitt, Roberts, and
    Farid) no longer set the boundary pixels to 0 when a mask is not
    supplied. This was changed because the boundary mode for
    scipy.ndimage.convolve is now 'reflect', which allows meaningful
    values at the borders for these filters. To retain the old
    behavior, pass mask=np.ones(image.shape, dtype=bool) (#4347)
    + When out_range is a range of numbers and not a dtype in
    :func:`skimage.exposure.rescale_intensity`, the output data type
    will always be float (#4585)
    + The values returned by
    :func:`skimage.exposure.equalize_adapthist` will be slightly
    different from previous versions due to different rounding
    behavior (#4585)
    + Move masked_register_translation from feature to registration
    (#4503)
    + Move register_translation from skimage.feature to
    skimage.registration (#4502)
    + Move watershed from morphology to segmentation (#4443)
    + Rename draw.circle() to draw.disk() (#4428)
    + The forward and backward maps returned by
    :func:`skimage.segmentation.relabel_sequential` are no longer
    NumPy arrays, but more memory-efficient ArrayMap objects that
    behave the same way for mapping. See the relabel_sequential
    documentation for more details. To get NumPy arrays back, cast
    it as a NumPy array: np.asarray(forward_map) (#4612)
  * Bugfixes
    + denoise_wavelet: For user-supplied sigma, if the input image
    gets rescaled via img_as_float, the same scaling will be applied
    to sigma to preserve the relative scale of the noise
    estimate. To restore the old, behaviour, the user can manually
    specify rescale_sigma=False.
    + Fix Frangi artefacts around the image (#4343)
    + Fix Negative eigenvalue in inertia_tensor_eigvals due to
    floating point precision (#4589)
    + Fix morphology.flood for F-ordered images (#4556)
    + Fix h_maxima/minima strange behaviors on floating point image
    input (#4496)
    + Fix peak_local_max coordinates ordering (#4501)
    + Sort naturally peaks coordinates of same amplitude in
    peak_local_max (#4582)
    + Fix denoise_nl_means data type management (#4322)
    + Update rescale_intensity to prevent under/overflow and produce
    proper output dtype (#4585)
  * Deprecations
    + The minimal supported Python version by this release is 3.6.
    + Parameter inplace in skimage.morphology.flood_fill has been
    deprecated in favor of in_place and will be removed in version
    scikit-image 0.19.0 (#4250).
    + skimage.segmentation.circle_level_set has been deprecated and
    will be removed in 0.19. Use skimage.segmentation.disk_level_set
    instead.
    + skimage.draw.circle has been deprecated and will be removed in
    0.19. Use skimage.draw.disk instead.
    + Deprecate filter argument in iradon due to clash with python
    keyword (#4158)
    + Deprecate marching_cubes_classic (#4287)
    + Change label2rgb default background value from -1 to 0 (#4614)
    + Deprecate rgb2grey and grey2rgb (#4420)
    + Complete deprecation of circle in morphsnakes (#4467)
    + Deprecate non RGB image conversion in rgb2gray (#4838, #4439),
    and deprecate non gray scale image conversion in gray2rgb
    (#4440)
* Fri Jan 17 2020 Tomáš Chvátal <tchvatal@suse.com>
- Skip 2 failing tests on 32bit
- Do not buildrequire nose
* Wed Dec  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Use xdist to speed up the testing that takes bit too much time
* Sat Nov  9 2019 Arun Persaud <arun@gmx.de>
- specfile:
  * remove two patched (included upstream):
  - fix_numpy_1_17.patch
  - fix_numpy_matrix_warning_test.patch
  * add test requirement imageio
- update to version 0.16.2 (bsc#1157707):
  * Bug fixes
    + Migrate to networkx 2.x (#4236, #4237)
    + Sync required numpy and dask to runtime versions (#4233, #4239)
    + Fix wrong argument parsing in structural_similarity (#4246,
    [#4247])
    + Fix active contour gallery example after change to rc
    coordinates (#4257, #4262)
- changes from version 0.16.1:
  * New Features
    + New `skimage.evaluate` module containing simple metrics (mse,
    nrme, psd) and segmentation metrics (adapted rand error,
    variation of information) (#4025)
    + n-dimensional TV-L1 optical flow algorithm for registration --
    `skimage.registration.optical_flow_tvl1` (#3983)
    + Draw a line in an n-dimensional array -- `skimage.draw.line_nd`
    (#2043)
    + 2D Farid & Simoncelli edge filters - `skimage.filters.farid`,
    `skimage.filters.farid_h`, and `skimage.filters.farid_v` (#3775)
    + 2D majority voting filter assigning to each pixel the most
    commonly occurring value within its neighborhood --
    `skimage.filters.majority` (#3836, #3839)
    + Multi-level threshold "multi-Otsu" method, a thresholding
    algorithm used to separate the pixels of an input image into
    several classes by maximizing the variances between classes --
    `skimage.filters.threshold_multiotsu` (#3872, #4174)
    + New example data -- `skimage.data.shepp_logan_phantom`,
    `skimage.data.colorwheel`, `skimage.data.brick`,
    `skimage.data.grass`, `skimage.data.roughwall`,
    `skimage.data.cell` (#3958, #3966)
    + Compute and format image region properties as a table
  - -.measure.regionprops_table` (#3959)
    + Convert a polygon into a mask -- `skimage.draw.poly2mask`
    (#3971, #3977)
    + Visual image comparison helper `skimage.util.compare_images`,
    that returns an image showing the difference between two input
    images (#4089)
    + `skimage.transform.warp_polar` to remap image into polar or
    log-polar coordinates. (#4097)
  * Improvements
    + RANSAC: new option to set initial samples selected for
    initialization (#2992)
    + Better repr and str for `skimage.transform.ProjectiveTransform`
    (#3525, #3967)
    + Better error messages and data type stability to
    `skimage.segmentation.relabel_sequential` (#3740)
    + Improved compatibility with dask arrays in some image
    thresholding methods (#3823)
    + `skimage.io.ImageCollection` can now receive lists of patterns
    (#3928)
    + Speed up `skimage.feature.peak_local_max` (#3984)
    + Better error message when incorrect value for keyword argument
    `kind` in.color.label2rgb` (#4055)
    + All functions from `skimage.drawing` now supports multi-channel
    2D images (#4134)
  * API Changes
    + Deprecated subpackage "skimage.novice" has been removed.
    + Default value of "multichannel" parameters has been set to False
    in `skimage.transform.rescale`,
    `skimage.transform.pyramid_reduce`,
    `skimage.transform.pyramid_laplacian`,.transform.pyramid_gaussian`,
    and `skimage.transform.pyramid_expand`. Guessing is no longer
    performed for 3D.
    + Deprecated argument "visualise" has been removed
    from.feature.hog`. Use "visualize" instead.¨
    + `skimage.transform.seam_carve` has been completely removed from
    the library due to licensing restrictions.
    + Parameter "as_grey" has been removed from `skimage.data.load`
    and `skimage.io.imread`. Use "as_gray" instead.
    + Parameter "min_size" has been removed from
    `skimage.morphology.remove_small_holes`. Use "area_threshold"
    instead.
    + Deprecated "correct_mesh_orientation" in `skimage.measure` has
    been removed.
    + `skimage.measure._regionprops` has been completely switched to
    using-column coordinates. Old x-y interface is not longer
    available.
    + Default value of "behavior" parameter has been set to "ndimage"
    in `skimage.filters.median`.
    + Parameter "flatten" in `skimage.io.imread` has been removed in
    favor of "as_gray".
    + Parameters "Hxx, Hxy, Hyy" have been removed from
    `skimage.feature.corner.hessian_matrix_eigvals` in favor of
    "H_elems".
    + Default value of "order" parameter has been set to "rc" in
    `skimage.feature.hessian_matrix`.
    + "skimage.util.img_as_*" functions no longer raise precision
    and/or loss warnings.
  * Bugfixes
    + Corrected error with scales attribute in ORB.detect_and_extract
    (#2835) The scales attribute wasn't taking into account the
    mask, and thus was using an incorrect array size.
    + Correct for bias in Inverse Randon Transform
    (`skimage.transform.irandon`) (#3067) Fixed by using the Ramp
    filter equation in the spatial domain as described in the
    reference
    + Fix a rounding issue that caused a rotated image to have a
    different size than the input (`skimage.transform.rotate`)
    (#3173)
    + RANSAC uses random subsets of the original data and not
    bootstraps. (#3901, #3915)
    + Canny now produces the same output regardless of dtype (#3919)
    + Geometry Transforms: avoid division by zero & some degenerate
    cases (#3926)
    + Fixed float32 support in denoise_bilateral and
    denoise_tv_bregman (#3936)
    + Fixed computation of Meijering filter and avoid
    ZeroDivisionError (#3957)
    + Fixed `skimage.filters.threshold_li` to prevent being stuck on
    stationnary points, and thus at local minima or maxima (#3966)
    + Edited `skimage.exposure.rescale_intensity` to return input
    image instead of nans when all 0 (#4015)
    + Fixed `skimage.morphology.medial_axis`. A wrong indentation in
    Cython caused the function to not behave as intended. (#4060)
    + Fixed `skimage.restoration.denoise_bilateral` by correcting the
    padding in the gaussian filter(#4080)
    + Fixed `skimage.measure.find_contours` when input image contains
    NaN.  Contours interesting NaN will be left open (#4150)
    + Fixed `skimage.feature.blob_log` and `skimage.feature.blob_dog`
    for 3D images and anisotropic data (#4162)
    + Fixed `skimage.exposure.adjust_gamma`,
    `skimage.exposure.adjust_log`, and
    `skimage.exposure.adjust_sigmoid` such that when provided with a
    1 by 1 ndarray, it returns 1 by 1 ndarrays and not single number
    floats (#4169)
  * Deprecations
    + Parameter "neighbors" in `skimage.measure.convex_hull_object`
    has been deprecated in favor of "connectivity" and will be
    removed in version 0.18.0.
    + The following functions are deprecated in favor of the
    `skimage.metrics` module (#4025):
  - `skimage.measure.compare_mse`
  - `skimage.measure.compare_nrmse`
  - `skimage.measure.compare_psnr`
  - `skimage.measure.compare_ssim`
    + The function `skimage.color.guess_spatial_dimensions` is
    deprecated and will be removed in 0.18 (#4031)
    + The argument "bc" in `skimage.segmentation.active_contour` is
    deprecated.
    + The function `skimage.data.load` is deprecated and will be
    removed in 0.18 (#4061)
    + The function `skimage.transform.match_histogram` is deprecated
    in favor of `skimage.exposure.match_histogram` (#4107)
    + The parameter "neighbors" of
    `skimage.morphology.convex_hull_object` is deprecated.
    + The `skimage.transform.randon_tranform` function will convert
    input image of integer type to float by default in 0.18. To
    preserve current behaviour, set the new argument
    "preserve_range" to True. (#4131)
  * For further documentation improvements and misc pull request see
    https://github.com/scikit-image/scikit-image/blob/v0.16.x/doc/release/release_0.16.rst
* Wed Jul 31 2019 Todd R <toddrme2178@gmail.com>
- Add fix_numpy_1_17.patch
  Fixes building with numpy 1.17
  From gh#scikit-image/scikit-image#3992
* Sat Jul 27 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- do not write unreproducible test_random_walker.cpython-37-PYTEST.pyc
  files (boo#1062303)
* Tue Jul 23 2019 Todd R <toddrme2178@gmail.com>
  + New Features
  * N-dimensional flood fill, with tolerance
  * Attribute operators
  * Extension of register_translation to enable subpixel precision in 3D and
    optionally disable error calculation
  * unsharp mask filtering
  * New options ``connectivity``, ``indices`` and ``allow_borders`` for
    ``skimage.morphology.local_maxima`` and ``local_minima``.
  * Image translation registration for masked data
    (``skimage.feature.masked_register_translation``)
  * Frangi (vesselness), Meijering (neuriteness), and Sato (tubeness) filters
  * Allow float->float conversion of any range
  * Let lower precision float arrays pass through ``img_as_float``
  * Lazy apply_parallel (allows optimization of dask array operations)
  * Add range option for histogram.
  * Add histogram matching
  + Improvements
  * Replace ``morphology.local_maxima`` with faster flood-fill based Cython
    version
  * ``skivi`` is now using ``qtpy`` for Qt4/Qt5/PySide/PySide2 compatibility (a
    new optional dependency).
  * Performance is now monitored by
    `Airspeed Velocity <https://asv.readthedocs.io/en/stable/>`_. Benchmark
    results will appear at https://pandas.pydata.org/speed/
  * Speed up inner loop of GLCM
  * Allow tuple to define kernel in threshold_niblack and threshold_sauvola
  * Add support for anisotropic blob detection in blob_log and blob_dog
  + API Changes
  * ``skimage.transform.seam_carve`` has been removed because the algorithm is
    patented.
  * Parameter ``dynamic_range`` in ``skimage.measure.compare_psnr`` has been
    removed. Use parameter ``data_range`` instead.
  * imageio is now the preferred plugin for reading and writing images.
  * imageio is now a dependency of scikit-image.
  * ``regular_grid`` now returns a tuple instead of a list for compatibility
    with numpy 1.15
  * ``colorconv.separate_stains`` and ``colorconv.combine_stains`` now uses
    base10 instead of the natural logarithm as discussed in issue #2995.
  * Default value of ``clip_negative`` parameter in ``skimage.util.dtype_limits``
    has been set to ``False``.
  * Default value of ``circle`` parameter in ``skimage.transform.radon``
    has been set to ``True``.
  * Default value of ``circle`` parameter in ``skimage.transform.iradon``
    has been set to ``True``.
  * Default value of ``mode`` parameter in ``skimage.transform.swirl``
    has been set to ``reflect``.
  * Deprecated ``skimage.filters.threshold_adaptive`` has been removed.
    Use ``skimage.filters.threshold_local`` instead.
  * Default value of ``multichannel`` parameter in
    ``skimage.restoration.denoise_bilateral`` has been set to ``False``.
  * Default value of ``multichannel`` parameter in
    ``skimage.restoration.denoise_nl_means`` has been set to ``False``.
  * Default value of ``mode`` parameter in ``skimage.transform.resize``
    and ``skimage.transform.rescale`` has been set to ``reflect``.
  * Default value of ``anti_aliasing`` parameter in ``skimage.transform.resize``
    and ``skimage.transform.rescale`` has been set to ``True``.
  * Removed the ``skimage.test`` function. This functionality can be achieved
    by calling ``pytest`` directly.
  * ``morphology.local_maxima`` now returns a boolean array
  + Bugfixes
  * Correct bright ridge detection for Frangi filter
  * ``skimage.morphology.local_maxima`` and ``skimage.morphology.local_minima``
    no longer raise an error if any dimension of the image is smaller 3 and
    the keyword ``allow_borders`` was false.
  * ``skimage.morphology.local_maxima`` and ``skimage.morphology.local_minima``
    will return a boolean array instead of an array of 0s and 1s if the
    parameter ``indices`` was false.
  * When ``compare_ssim`` is used with ``gaussian_weights`` set to True, the
    boundary crop used when computing the mean structural similarity will now
    exactly match the width of the Gaussian used. The Gaussian filter window is
    also now truncated at 3.5 rather than 4.0 standard deviations to exactly match
    the original publication on the SSIM. These changes should produce only a very
    small change in the computed SSIM value. There is no change to the existing
    behavior when ``gaussian_weights`` is False.
  * erroneous use of cython wrap around
  * Speed up block reduce by providing the appropriate parameters to numpy
  * Add urllib.request again
  * Repeat pixels in reflect mode when image has dimension 1
  * Improve Li thresholding
  + Deprecations
  * Python 2 support has been dropped. Users should have Python >= 3.5.
  * ``skimage.util.montage2d`` has been removed. Use ``skimage.util.montage`` instead.
  * ``skimage.novice`` is deprecated and will be removed in 0.16.
  * ``skimage.transform.resize`` and ``skimage.transform.rescale`` option
    ``anti_aliasing`` has been enabled by default.
  * ``regionprops`` will use row-column coordinates in 0.16. You can start
    using them now with ``regionprops(..., coordinates='rc')``. You can silence
    warning messages, and retain the old behavior, with
    ``regionprops(..., coordinates='xy')``. However, that option will go away
    in 0.16 and result in an error. This change has a number of consequences.
    Specifically, the "orientation" region property will measure the
    anticlockwise angle from a *vertical* line, i.e. from the vector (1, 0) in
    row-column coordinates.
  * ``skimage.morphology.remove_small_holes`` ``min_size`` argument is deprecated
    and will be removed in 0.16. Use ``area_threshold`` instead.
  * ``skimage.filters.median`` will change behavior in the future to have an
    identical behavior as ``scipy.ndimage.median_filter``. This behavior can be
    set already using ``behavior='ndimage'``. In 0.16, it will be the default
    behavior and removed in 0.17 as well as the parameter of the previous
    behavior (i.e., ``mask``, ``shift_x``, ``shift_y``) will be removed.
  + Documentation improvements
  * Correct rotate method's center parameter doc
  * Add Sphinx copybutton
  * Add glossary to the documentation
  * Add image of retina to our data
  * Add microaneurysms() to gallery
  * Better document remove_small_objects behaviour: int vs bool
  * Linking preserve_range parameter calls to docs
  * Update the documentation regarding datalocality
  * Specify conda-forge channel for scikit-image conda install
  * Turn DOIs into web links in docstrings
  * Update documentation for regionprops
  * DOC: Improve the RANSAC gallery example
  * DOC: "feature.peak_local_max" : explanation of multiple same-intensity peaks returned by the function; added details on ``exclude_border`` parameter
  + Improvements
  * MNT: handle a deprecation warning for np.linspace and floats for the num parameter
  * TST: numpy empty arrays are not inherently Falsy
  * handle warning in scipy cdist for unused parameters
  * MNT: don't use filter_warnings in test suite.
  * Add doc notes on setting up the build environment
  * Release the GIL in numerous cython functions
  * Cython touchups to use float32 and float64
  * rank_filters: Change how the bitdepth and max_bin are computed to ensure exact warnings.
  * Rank: Optimize OTSU filter
  * Rank - Fix rank entropy and OTSU tests
  * delay importing pyplot in manual segmentation
  * Get rid of the requirements-parser dependency
  * filter warning from ``correct_mesh_orientation`` in tests
  * cloudpickle is really a doc dependency, not a core one
  * optional dependencies on pip
  * Fewer test warnings in 3.7
  * collections.abc nit
  * Streamlined issue template
  * Tighten the PR Template
  * Use language level to 3 in cython for future compatibility
  * Update ISSUE_TEMPLATE.md with info about numpy and skimage versions
  * Use relative imports for many cython modules
  * Pass tests that don't raise floating point exceptions on arm with soft-fp
  + Other improvements
  * BUG: Fix greycoprops correlation always returning 1
  * Add section on API discovery via ``skimage.lookfor``
  * Speedup 2D warping for affine transformations
  * Credit Reviewers in Release Notes
  * Added small galleries in the API
  * Use skimage gaussian filter to avoid integer rounding artifacts
  * Remove Python 2 compatibility
  * Add ``rectangle_perimeter`` feature to ``skimage.draw``
  * Update installation instructions to reference existing requirements specification
  * Updated release notes with pre 0.13.1 phase
  * Release guidelines update
  * Ensure we are installing with / running on Python 3
  * Hide warnings in test_unsharp_mask
  * Process 0.15 deprecations
  * Documentation: always use dev branch javascript
  * Add initial airspeed velocity (asv) framework
  * Supress warnings for flatten during io testing
  * Recover from exceptions in filters.try_all_threshold()
  * Fix skimage.test() to run the unittests
  * skivi: Use qtpy to handle different Qt versions
  * Refactor python version checking.
  * Move data_dir to within ``data/__init__.py``
  * Move the definition of lookfor out of __init__.py
  * Normalize the package number to PEP440
  * Remove skimage.test as it was never used.
  * Added a message about qtpy to the INSTALL.rst
  * Regression fix: Travis should fail if tests fail
  * Set minimum cython version to ``0.23.4``
  * Add rgba2rgb to API docs
  * Minor doc formatting fixes in video.rst
  * Decrease the verbosity of the testing
  * Speedup rgb2gray using matrix multiply
  * Add instructions for meeseeksdev to PR template
  * Remove installation instructions for video packages
  * Big image labeling fix
  * Handle dask deprecation in cycle_spin
  * Fix Qt viewer painttool indexing
  * build_versions.py is no longer hard coded.
  * Remove dtype constructor call in exposure.rescale_intensity
  * Various updates to the ASV benchmarks
  * Add a link to stack overflow on github README
  * MAINT: remove encoding information in file headers (python 3)
  * Build tools: Dedicate a --pre build in appveyor and ensure other builds don't download --pre
  * Fix the human readable error message on a bad build.
  * Respect input array type in apply_parallel by default
  * Travis cleanup pip commands
  * Add benchmarks for morphology.watershed
  * Correcte docstring formatting so that code block is displayed as code
  * Defer skimage.io import of matplotlib.pyplot until needed
  * Add benchmark for Sobel filters
  * Remove cython md5 hashing since it breaks the build process
  * Fix typo in documentation.
  * Issue 3156: skimage/__init__.py Update docstring and fix import *
  * Object detector module
  * Do not import submodules while building
  * Add benchmark suite for canny
  * improve segmentation.felzenszwalb document #3264
  * Update _canny.py
  * Add benchmark suite for histogram equalization
  * fix link to equalist_hist blog reference
  * .gitignore: novice: Ignore save-demo.jpg
  * Guide the user of denoise_wavelet to choose an orthogonal wavelet.
  * Remove unused lib in skimage/__init__.py
  * BUILD: Add pyproject.toml to ensure cython is present
  * Handle intersphinx and mpl deprecation warnings in docs
  * Minor PEP8 fixes
  * cython: check for presence of cpp files during install from sdist
  * appveyor: don't upload any artifacts
  * Add benchmark suite for hough_line()
  * Novice skip url test
  * Remove benchmarks from wheel
  * Add license file to the wheel (binary) distribution
  * codecov: ignore build scripts in coverage and don't comment on PRs
  * Matplotlib 2.2.3 +  PyQt5.11
  * Allow @hmaarrfk to mention MeeseeksDev to backport.
  * Add Python 3.7 to the test matrix
  * Fix deprecated keyword from dask
  * Incompatible modes with anti-aliasing in skimage.transform.resize
  * Missing cval parameter in threshold_local
  * Avoid Sphinx 1.7.8
  * Show our data in the gallery
  * Minor updates to grammar in numpy images page
  * assert_all_close doesn't exist, make it ``assert_array_equal``
  * Better behavior of Gaussian filter for arrays with a large number of dimensions
  * Allow import/execution with -OO
  * Mark tests known to fail on 32bit architectures with xfail
  * Hardcode the inputs to test_ssim_grad
  * TST: make test_wavelet_denoising_levels compatible with PyWavelets 1.0
  * Allow tifffile.py to handle I/O.
  * Add explicit Trove classifier for Python 3
  * Fix error in contribs.py
  * MAINT: remove pyside restriction since we don't support Python 3.4 anymore
  * Build tools: simplify how MPL_DIR is obtained.
  * Build tools: Don't run tests twice in travis.
  * Build tools: Add an OSX build with optional dependencies.
  * MAINT: Reverted the changes in #3300 that broke the MINIMIUM_REQUIREMENTS tests
  * MNT: Convert links using http to https
  * MAINT: Use upstream colormaps now that matplotlib has been upgraded
  * Build tools: Make pyamg an optional dependency and remove custom logic
  * Build tools: Fix PyQt installed in minimum requirements build
  * MNT: multiprocessing should always be available since we depend on python >=2.7
  * MAINT Use np.full instead of cst*np.ones
  * DOC: Fix LaTeX build via ``make latexpdf``
  * Update instructions et al for releases after 0.14.1
  * Remove code specific to python 2
  * Fix default value of ``methods`` in ``_try_all`` to avoid exception
  * Fix morphology.local_maxima for input with any dimension < 3
  * Use raw strings to avoid unknown escape symbol warnings
  * Speed up xyz2rgb by clipping output in place
  * MNT; handle deprecation warnings in tifffile
  * Build tools: TST: filter away novice deprecation warnings during testing
  * Build tools: don't use the pytest.fixtures decorator anymore in class fixtures
  * Preserving the fill_value of a masked array
  * Fix VisibleDeprecationWarning from np.histogram, normed=True
  * Build Tools: DOC: Document that now PYTHONOPTMIZE build is blocked by SciPy
  * DOC: Replace broken links by webarchive equivalent links
  * FIX: making the plot_marching_cubes example visible.
  * Avoid Travis failure regarding ``skimage.lookfor``
  * Fix Python executable for sphinx-build in docs Makefile
  * Build Tools: Blacklist specific Cython versions
  * Fix typos
  * Add "optional" indications to docstrings
  * Rename 'mnxc' (masked normalize cross-correlation) to something more descriptive
  * Random walker bug fix: no error should be raised when there is nothing to do
  * Various minor edits for active contour
  * Fix range for uint32 dtype in user guide
  * Raise meaningful exception in warping when image is empty
  * DOC: Development installation instructions for Ubuntu are missing tkinter
  * Better gallery examples and tests for masked translation registration
  * DOC: make more docstrings compliant with our standards
  * Build tools: Remove restriction on simpleitk for python 3.7
  * Speedup and add benchmark for ``skeletonize_3d``
  * Update requirements/README.md on justification of matplotlib 3.0.0 in favor of #3476
  * Doc enhancements around denoising features.
  * Use 'getconf _NPROCESSORS_ONLN' as fallback for nproc in Makefile of docs
  * Fix matplotlib set_*lim API deprecations
  * Switched from np.power to np.cbrt
  * Filtered out DeprecationPendingWarning for matrix subclass
  * Add RGB to grayscale example to gallery
  * Build tools: Refactor check_sdist so that it takes a filename as a parameter
  * Turn dask to an optional requirement
  * _marching_cubes_lewiner_cy: mark char as signed
  * Hyperlink DOIs to preferred resolver
  * Missing parameter description in ``morphology.reconstruction`` docstring #3581
  * Update chat location
  * Remove orphan code (skimage/filters/_ctmf.pyx).
  * More explicit example title, better list rendering in plot_cycle_spinning.py
  * Add rgb to hsv example in the gallery
  * Update documentation of ``perimeter`` and add input validation
  * Additionnal mask option to clear_border
  * Set up CI with Azure Pipelines
  * [MRG] EHN: median filters will accept floating image
  * Update Travis-CI to xcode 10.1
  * Minor tweaks to _mean_std code
  * Add explicit ordering of gallery sections
  * Delete broken links
  * Build tools: Fix test_mpl_imshow for matplotlib 2.2.3 and numpy 1.16
  * First draft of core dev guide
  * Add more details about the home page build process
  * Ensure images resources with long querystrings can be read
  * Delay matplotlib import in skimage/future/manual_segmentation.py
  * make the low contrast check optional when saving images
  * Correctly ignore release notes auto-generated for docs
  * Remove MANIFEST file when making the 'clean' target
  * Clarify return values in _overlap docstrings in feature/blob.py
  * Contribution script: allow specification of GitHub development branch
  * Update core dev guide: deprecation, contributor guide, required experience
  * Add release notes for 0.14.2
  * FIX gallery: Add multichannel=True to match_histogram
  * MAINT Minor code style improvements
  * Pass parameters through tifffile plugin
  * DOC unusused im3d_t in example
  * Remove wrong cast of Py_ssize_t to int
  * Build tools: allow python 3.7 to fail, but travis to continue
  * Build tools: remove pyproject.toml
  * Fix ValueError: not enough values to unpack
  * Several fixes for heap.pyx
  * Enable the faulthandler module during testing
  * Build tools: Fix Python 3.7 builds on travis
  * Replace np.einsum with np.tensordot in _upsampled_dft
  * Fix potential use of NULL pointers
  * Fix potential memory leak
  * Fix potential use of NULL pointers
  * Fix and improve core_cy.pyx
  * Build tools: Downgrade Xcode to 9.4 on master
  * Improve visual_test.py
  * Updated painttool to work with color images and properly scale labels.
  * Add image.sc forum badge to README
  * Blacklist PyQt 5.12.0 on Travis
  * Build tools: Fix matplotlib + qt 5.12 the same way upstream does it
  * gallery: remove xx or yy  sorted directory names
  * Allow for f-contiguous 2D arrays in convex_hull_image
  * Build tools: Set astropy minimum requirement to 1.2 to help the CIs.
  * Avoid NumPy warning while stacking arrays.
  * Set CC0 for microaneurysms
  * Unify LICENSE files for easier interpretation
  * Readme: Remove expectation for future fix from matplotlib
  * Improved documentation/test in ``flood()``
  * Use ssize_t in denoise cython
  * Removed non-existent parameter in docstring
  * Remove redundant point in draw.polygon docstring example
  * Ensure watershed auto-markers respect mask
- Add fix_numpy_matrix_warning_test.patch
  to fixup the test for the warnings for scipy 1.3 and the
  matrix subsclass. From gh#scikit-image/scikit-image#3869
* Sun Jan 20 2019 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 0.14.2:
  * API changes
    + "skimage.measure.regionprops" no longer removes singleton
    dimensions from label images (#3284). To recover the old
    behavior, replace "regionprops(label_image)" calls with
    "regionprops(np.squeeze(label_image))"
  * Bug fixes
    + Address deprecation of NumPy "_validate_lengths" (backport of
    [#3556])
    + Correctly handle the maximum number of lines in Hough transforms
    (backport of #3514)
    + Correctly implement early stopping criterion for rank kernel
    noise filter (backport of #3503)
    + Fix "skimage.measure.regionprops" for 1x1 inputs (backport of
    [#3284])
  * Enhancements
    + Rewrite of "local_maxima" with flood-fill (backport of #3022,
    [#3447])
  * Build Process & Testing
    + Dedicate a "--pre" build in appveyor (backport of #3222)
    + Avoid Travis-CI failure regarding "skimage.lookfor" (backport of
    [#3477])
    + Stop using the "pytest.fixtures" decorator (#3558)
    + Filter out DeprecationPendingWarning for matrix subclass (#3637)
    + Fix matplotlib test warnings and circular import (#3632)
* Mon Oct  8 2018 Arun Persaud <arun@gmx.de>
- specfile:
  * increase Cython requirement to 0.23.4
- update to version 0.14.1:
  * Bug fixes
    + skimage.color.adapt_rgb was applying input functions to the
    wrong axis (#3097)
    + CollectionViewer now indexes correctly (it had been broken by an
    update to NumPy indexing) (#3288)
    + Handle deprecated indexing-by-list and NumPy matrix from NumPy
    1.15 (#3238, #3242, #3292)
    + Fix incorrect inertia tensor calculation (#3303) (Special thanks
    to JP Cornil for reporting this bug and for their patient help
    with this fix)
    + Fix missing comma in __all__ listing of moments_coord_central,
    so it and moments_normalized can now be correctly imported from
    the measure namespace (#3374)
    + Fix background color in label2rgb(..., kind='avg') (#3280)
  * Enhancements
    + "Reflect" mode in transforms now works fine when an image
    dimension has size 1 (#3174)
    + img_as_float now allows single-precision (32-bit) float arrays
    to pass through unmodified, rather than being up-converted to
    64-bit (#3110, #3052, #3391)
    + Speed up rgb2gray computation (#3187)
    + The scikit-image viewer now works with different PyQt versions
    (#3157)
    + The cycle_spin function for enhanced denoising works
    single-threaded when dask is not installed now (#3218)
    + scikit-image's io module will no longer inadvertently set the
    matplotlib backend when imported (#3243)
    + Fix deprecated get keyword from dask in favor of scheduler
    (#3366)
    + Add missing cval parameter to threshold_local (#3370)
  * API changes
    + Remove deprecated dynamic_range in measure.compare_psnr (#3313)
  * Documentation
    + Improve the documentation on data locality (#3127)
    + Improve the documentation on dealing with video (#3176)
    + Update broken link for Canny filter documentation (#3276)
    + Fix incorrect documentation for the center parameter of
    skimage.transform.rotate (#3341)
    + Fix incorrect formatting of docstring in measure.profile_line
    (#3236)
  * Build process / development
    + Ensure Cython is 0.23.4 or newer (#3171)
    + Suppress warnings during testing (#3143)
    + Fix skimage.test (#3152)
    + Don't upload artifacts to AppVeyor (there is no way to delete
    them) (#3315)
    + Remove import * from the scikit-image package root (#3265)
    + Allow named non-core contributors to issue MeeseeksDev commands
    (#3357, #3358)
    + Add testing in Python 3.7 (#3359)
    + Add license file to the binary distribution (#3322)
    + lookfor is no longer defined in __init__.py but rather imported
    to it (#3162)
    + Add pyproject.toml to ensure Cython is present before building
    (#3295)
    + Add explicit Python version Trove classifiers for PyPI (#3417)
    + Ignore known test failures in 32-bit releases, allowing 32-bit
    wheel builds (#3434)
    + Ignore failure to raise floating point warnings on certain ARM
    platforms (#3337)
    + Fix tests to be compatible with PyWavelets 1.0 (#3406)
* Sun Sep  2 2018 arun@gmx.de
- specfile:
  * update copyright year
  * TASKS file not in tar-ball anymore, removed it, added CONTRIBUTING.txt file
- update to version 0.14.0:
  * New Features
    + Lookfor function to search across the library:
    skimage.lookfor. (#2713)
    + nD support for skimage.transform.rescale,
    skimage.transform.resize, and skimage.transform.pyramid_*
    transforms. (#1522)
    + Chan-Vese segmentation algorithm. (#1957)
    + Manual segmentation with matplotlib for fast data annotation:
    skimage.future.manual_polygon_segmentation,
    skimage.future.manual_lasso_segmentation. (#2584)
    + Hysteresis thresholding:
    skimage.filters.apply_hysteresis_threshold. (#2665)
    + Segmentation with morphological snakes:
    skimage.segmentation.morphological_chan_vese (2D),
    skimage.segmentation.morphological_geodesic_active_contour (2D
    and 3D). (#2791)
    + nD support for image moments: skimage.measure.moments_central,
    skimage.measure.moments_central,
    skimage.measure.moments_normalized,
    skimage.measure.moments_hu. This change leads to 3D/nD
    compatibility for many regionprops. (#2603)
    + Image moments from coordinate input:
    skimage.measure.moments_coords,
    skimage.measure.moments_coords_central. (#2859)
    + Added 3D support to blob_dog and blob_log. (#2854)
    + Inertia tensor and its eigenvalues can now be computed outside
    of regionprops; available in
    skimage.measure.inertia_tensor. (#2603)
    + Cycle-spinning function for approximating shift-invariance by
    averaging results from a series of spatial shifts:
    skimage.restoration.cycle_spin. (#2647)
    + Haar-like feature: skimage.feature.haar_like_feature,
    skimage.feature.haar_like_feature_coord,
    skimage.feature.draw_haar_like_feature. (#2848)
    + Data generation with random_shapes function:
    skimage.draw.random_shapes. (#2773)
    + Subset of LFW (Labeled Faces in the Wild) database:
    skimage.data.cbcl_face_database. (#2905)
    + Fully reworked montage function (now with a better padding
    behavior): skimage.util.montage. (#2626)
    + YDbDr colorspace conversion routines: skimage.color.rgb2ydbdr,
    skimage.color.ydbdr2rgb. (#3018)
  * Improvements
    + VisuShrink method for
    skimage.restoration.denoise_wavelet. (#2470)
    + New max_ratio parameter for
    skimage.feature.match_descriptors. (#2472)
    + skimage.transform.resize and skimage.transform.rescale have a
    new anti_aliasing option to avoid aliasing artifacts when
    down-sampling images. (#2802)
    + Support for multichannel images for skimage.feature.hog. (#2870)
    + Non-local means denoising (skimage.restoration.denoise_nl_means)
    has a new optional parameter, sigma, that can be used to specify
    the noise standard deviation. This enables noise-robust patch
    distance estimation. (#2890)
    + Mixed dtypes support for skimage.measure.compare_ssim,
    skimage.measure.compare_psnr, etc. (#2893)
    + New alignment parameter in skimage.feature.plot_matches. (#2955)
    + New seed parameter in
    skimage.transform.probabilistic_hough_line. (#2960)
    + Various performance improvements. (#2821, #2878, #2967, #3035,
    [#3056], #3100)
  * Bugfixes
    + Fixed skimage.measure.regionprops.bbox_area returning incorrect
    value. (#2837)
    + Changed gradient and L2-Hys norm computation in
    skimage.feature.hog to closely follow the paper. (#2864)
    + Fixed skimage.color.convert_colorspace not working for YCbCr,
    YPbPr. (#2780)
    + Fixed incorrect composition of projective tranformation with
    inverse transformation. (#2826)
    + Fixed bug in random walker appearing when seed pixels are
    isolated inside pruned zones. (#2946)
    + Fixed rescale not working properly with different rescale
    factors in multichannel case. (#2959)
    + Fixed float and integer dtype support in
    skimage.util.invert. (#3030)
    + Fixed skimage.measure.find_contours raising StopIteration on
    Python 3.7. (#3038)
    + Fixed platform-specific issues appearing in Windows and/or
    32-bit environments. (#2867, #3033)
  * API Changes
    + skimage.util.montage. namespace has been removed, and
    skimage.util.montage.montage2d function is now available as
    skimage.util.montage2d.
    + skimage.morphology.binary_erosion now uses True as border value,
    and is now consistent with skimage.morphology.erosion.
  * Deprecations
    + freeimage plugin has been removed from skimage.io.
    + skimage.util.montage2d is deprecated and will be removed in
    0.15. Use skimage.util.montage function instead.
    + skimage.novice is deprecated and will be removed in 0.16.
    + skimage.transform.resize and skimage.transform.rescale have a
    new anti_aliasing option that avoids aliasing artifacts when
    down-sampling images. This option will be enabled by default in
    0.15.
    + regionprops will use row-column coordinates in 0.16. You can
    start using them now with regionprops(...,
    coordinates='rc'). You can silence warning messages, and retain
    the old behavior, with regionprops(...,
    coordinates='xy'). However, that option will go away in 0.16 and
    result in an error. This change has a number of
    consequences. Specifically, the "orientation" region property
    will measure the anticlockwise angle from a vertical line,
    i.e. from the vector (1, 0) in row-column coordinates.
    + skimage.morphology.remove_small_holes min_size argument is
    deprecated and will be removed in 0.16. Use area_threshold
    instead.
* Sat Sep 30 2017 arun@gmx.de
- update to version 0.13.1:
  * no upstream changelog available for 0.13.1
- 0.13.0 changelog available at: https://github.com/scikit-image/scikit-image/blob/master/doc/release/release_0.13.rst
* Mon Jun 12 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update source URL
- Update to version 0.13.0
  * No upstream changelog
* Mon Jan 11 2016 toddrme2178@gmail.com
- update to version 0.11.3:
  (no changelog entry, taken from git log)
  * Fix handling of non-gif and tiff files
  * Fix setup to allow installing from PyPI
  * Fix support for Sphinx 1.3
  * Add a helper function to check for low contrast
  * Fix RANSAC for invalid model estimation and confidence corner case
- Fix update-alternatives usage
* Sat Nov 23 2013 p.drouand@gmail.com
- Missing 0.9.3 tarball in previous commit; upload it and remove old
  tarball
* Mon Oct 21 2013 toddrme2178@gmail.com
- Update to 0.9.3
  * No upstream changelog
- Rename to python-scikit-image to match new naming policy
* Sat Oct 13 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- update version to 0.7.0
* Sun Mar 11 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- initial OBS Build (v0.5.0)
